@@ -1,6 +1,5 @@
 /*
- * Copyright (c) 2017-2018 Meltytech, LLC
- * Author: Dan Dennedy <dan@dennedy.org>
+ * Copyright (c) 2017-2019 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,10 +22,19 @@ function trackHeight(isCurves) {
 function scrollIfNeeded() {
     var x = producer.position * timeScale;
     if (!scrollView) return;
-    if (x > scrollView.flickableItem.contentX + scrollView.width - 50)
-        scrollView.flickableItem.contentX = x - scrollView.width + 50;
-    else if (x < 50)
-        scrollView.flickableItem.contentX = 0;
-    else if (x < scrollView.flickableItem.contentX + 50)
-        scrollView.flickableItem.contentX = x - 50;
+    if (settings.timelineCenterPlayhead) {
+        if (x > scrollView.flickableItem.contentX + scrollView.width * 0.5)
+            scrollView.flickableItem.contentX = x - scrollView.width * 0.5;
+        else if (x < scrollView.width * 0.5)
+            scrollView.flickableItem.contentX = 0;
+        else if (x < scrollView.flickableItem.contentX + scrollView.width * 0.5)
+            scrollView.flickableItem.contentX = x - scrollView.width * 0.5;
+    } else {
+        if (x > scrollView.flickableItem.contentX + scrollView.width - 50)
+            scrollView.flickableItem.contentX = x - scrollView.width + 50;
+        else if (x < 50)
+            scrollView.flickableItem.contentX = 0;
+        else if (x < scrollView.flickableItem.contentX + 50)
+            scrollView.flickableItem.contentX = x - 50;
+    }
 }
